#ifdef GL_ES   
    #define LOWP lowp
    precision mediump float;
#else
    #define LOWP
#endif
    
varying LOWP vec4 v_color;
varying vec2 v_texCoords;

uniform sampler2D u_texture;
uniform vec2 u_resolution;
uniform vec3 u_color;
uniform float u_leftright;
uniform float u_bottom;
uniform float u_top;
uniform float u_alpha;

const float SOFTNESS = 0.3;


float pcurve( float x, float a, float b ){
    float k = pow(a + b, a + b) / (pow(a, a) * pow(b, b));
    return k * pow(x, a) * pow(1.0 - x, b);
}

void main(){
	
	vec2 fragCoord = gl_FragCoord.xy;
	vec2 uv = fragCoord.xy / u_resolution.xy;
	
	//------------------------
	
	float x = pcurve(uv.y, u_bottom, u_top);
	float color = 1.0 - x;
	vec4 texColor = vec4(mix(u_color, u_color * color, 0.5), color * 0.8);

	//------------------------
	
	vec2 position = uv - vec2(0.5);
	position.x *= u_resolution.x / u_resolution.y;
	float len = length(position);
	float vignette = smoothstep(u_leftright - SOFTNESS, u_leftright, len);
	vec4 texColorV = vec4(mix(u_color, u_color * vignette, 0.5), vignette * 0.8);

	//------------------------
	
	vec4 resultColor = vec4(mix(texColorV, texColor, color));
	resultColor.a *= u_alpha;
	
	gl_FragColor = resultColor;
}